#include <string.h>
#include <gnome.h>
#include <glade/glade.h>

/* define version ourselves, really this should be defined by the build
   process if we use autoconf/automake */
#define VERSION "1.0"

/* a global pointer to the main window */
static GtkWidget *app;
/* a global pointer to the clist from the main window */
static GtkWidget *clist;

/* prototypes to avoid warnings */
void do_nothing(GtkWidget *w);
void run_about_dialog(GtkWidget *w);
void add_number(GtkWidget *w);

/* Just a spaceholder kind of a handler */
void
do_nothing(GtkWidget *w)
{
	gnome_app_message(GNOME_APP(app), "Doesn't do anything!");
}

/* Run the about dialog */
void
run_about_dialog(GtkWidget *w)
{
	GladeXML *xml;

	/* load the about1 dialog */
	xml = glade_xml_new("phonebook.glade", "about1");
	/* in case we can't load the interface, bail */
	if(!xml) {
		g_warning("We could not load the interface!");
		return;
	}

	/* unref the xml file as it's not needed anymore */
	gtk_object_unref(GTK_OBJECT(xml));
}

/* handler for the Add Number dialog "clicked" signal
   Note that the data for this handler will always be
   a GladeXML object */
static void
really_add_number(GtkWidget *w, int button, gpointer data)
{
	char *strings[2];
	GtkWidget *name_entry;
	GtkWidget *phone_entry;
	GladeXML *xml = data;

	/* if the button is not the first button (the OK) then just ignore
	   this call */
	if (button != 0)
		return;

	/* get widgets we need from the xml */
	name_entry = glade_xml_get_widget(xml, "add_name_entry");
	phone_entry = glade_xml_get_widget(xml, "add_phone_entry");

	/* setup the strings array with the added stuff */
	strings[0] = gtk_entry_get_text(GTK_ENTRY(name_entry));
	strings[1] = gtk_entry_get_text(GTK_ENTRY(phone_entry));

	/* append those to the clist on the main window */
	gtk_clist_append(GTK_CLIST(clist), strings);
}

/* run the Add Number dialog */
void
add_number(GtkWidget *w)
{
	GtkWidget *dialog;
	GladeXML *xml;

	/* load the dialog1 dialog */
	xml = glade_xml_new("phonebook.glade", "dialog1");
	/* in case we can't load the interface, bail */
	if(!xml) {
		g_warning("We could not load the interface!");
		return;
	}

	/* get widgets we need from the xml */
	dialog = glade_xml_get_widget(xml, "dialog1");

	/* set the parent of the dialog to be the main window */
	gnome_dialog_set_parent(GNOME_DIALOG(dialog), GTK_WINDOW(app));

	/* now connect the "clicked" signal on the dialog to the function
	   that actually adds the number to the 'clist', we pass the GladeXML
	   object to that handler as the data so that we can get information
	   out of the entry fields.  We use the gtk_signal_connect_full, so
	   that we can pass a gtk_object_unref function as the destroy
	   notification function.  This way the GladeXML object will be
	   unreferenced when dialog will get destroyed or this signal
	   otherwise disconnected */
	gtk_signal_connect_full(GTK_OBJECT(dialog), "clicked",
				GTK_SIGNAL_FUNC(really_add_number), NULL,
				xml, (GtkDestroyNotify)gtk_object_unref,
				FALSE, FALSE);
}

int
main(int argc, char *argv[])
{
	GladeXML *xml;
  
	/* initialize gnome */
	gnome_init("phonebook", VERSION, argc, argv);

	/* initialize glade for gnome */
	glade_gnome_init();

	/* load the main window (which is named app1) */
	xml = glade_xml_new("phonebook.glade", "app1");
	/* in case we can't load the interface, bail */
	if(!xml) {
		g_warning("We could not load the interface!");
		return 1;
	}

	/* setup our global app pointer to point to the main GnomeApp,
	   which is named 'app1' */
	app = glade_xml_get_widget(xml, "app1");
	/* setup our global clist pointer to point to the main GtkCList,
	   which is actually named 'clist1' */
	clist = glade_xml_get_widget(xml, "clist1");

	/* autoconnect any signals */
	glade_xml_signal_autoconnect(xml);

	/* we don't need the GladeXML object any more, so unref it
	   to save some memory */
	gtk_object_unref(GTK_OBJECT(xml));

	/* run the main loop */
	gtk_main();

	return 0;
}

